@@ -222,5 +222,27 @@ $(function() {
         event.preventDefault();
         hideImageRow($(this));
     });
+
+    var date_opts = {
+        dateFormat: "dd/mm/yy"
+    }
+    $('.datepicker').datepicker(date_opts);
+    if ($('#id_sold:checked').length == 0) {
+        $('#id_sold_date').hide();
+    }
+    $('body').on('change', '#id_sold', function() {
+        $this = $(this);
+        if ($('#id_sold:checked').length > 0) {
+            $('#id_sold_date').show();
+            var val = $('#id_sold_date').val()
+            if (val == '' || !val) {
+                $('#id_sold_date').val(TODAY);
+            }
+        }
+        else {
+            $('#id_sold_date').hide();
+            $('#id_sold_date').val('');
+        }
+    })
 });
 
